@@ -17,7 +17,7 @@ customer_analytics_data_bp = Blueprint('customer_analytics_data_bp', __name__,
                                  static_folder='static',
                                  url_prefix='/analytics/cust')
 
-logger = logging.getLogger('query')
+logger = logging.getLogger('analytics')
 
 query_customer_data_api = Api(customer_analytics_data_bp)
 
@@ -29,14 +29,14 @@ def query_customer_index():
 class QueryAllCustomerGrowthByYearMonth(CategoryAndCountQueryBaseResource):
     def prepare_query(self, **kwrgs):
         
-        year_month_from   = kwrgs.get('year_month_from')
-        year_month_to     = kwrgs.get('year_month_to')
+        date_range_from   = kwrgs.get('date_range_from')
+        date_range_to     = kwrgs.get('date_range_to')
         
         where_condition  = ''
         
-        if year_month_from and year_month_to:
-            where_condition = "WHERE _TABLE_SUFFIX BETWEEN '{year_month_from}' and '{year_month_to}'".format(year_month_from=year_month_from, 
-                                                                                                         year_month_to=year_month_to)
+        if date_range_from and date_range_to:
+            where_condition = "WHERE _TABLE_SUFFIX BETWEEN '{date_range_from}' and '{date_range_to}'".format(date_range_from=date_range_from, 
+                                                                                                         date_range_to=date_range_to)
         
         query = '''
             SELECT FORMAT_DATETIME('%Y-%m', RegisteredDateTime) as year_month, sum(count_by_date) as count
@@ -58,16 +58,16 @@ class QueryAllCustomerGrowthByYearMonth(CategoryAndCountQueryBaseResource):
 class QueryMerchantCustomerGrowthByYearMonth(CategoryAndCountQueryBaseResource):
     def prepare_query(self, **kwrgs):
         account_code      = kwrgs.get('account_code')
-        year_month_from   = kwrgs.get('year_month_from')
-        year_month_to     = kwrgs.get('year_month_to')
+        date_range_from   = kwrgs.get('date_range_from')
+        date_range_to     = kwrgs.get('date_range_to')
         
         account_code = account_code.replace('-','')
         
         where_condition  = ''
         
-        if year_month_from and year_month_to:
-            where_condition = "WHERE _TABLE_SUFFIX BETWEEN '{year_month_from}' and '{year_month_to}'".format(year_month_from=year_month_from, 
-                                                                                                         year_month_to=year_month_to)
+        if date_range_from and date_range_to:
+            where_condition = "WHERE _TABLE_SUFFIX BETWEEN '{date_range_from}' and '{date_range_to}'".format(date_range_from=date_range_from, 
+                                                                                                         date_range_to=date_range_to)
         
         query = '''
             SELECT FORMAT_DATETIME('%Y-%m', RegisteredDateTime) as year_month, sum(count_by_date) as count
