@@ -12,7 +12,7 @@ from trexlib.utils.log_util import get_tracelog
 
 from trexlib.utils.google.bigquery_util import execute_query, process_job_result_into_category_and_count, create_bigquery_client
 
-logger = logging.getLogger('analytic')
+logger = logging.getLogger('analytics')
 
 class QueryBaseResource(Resource):
     
@@ -25,9 +25,10 @@ class QueryBaseResource(Resource):
         
         logger.info('query=%s', query)
         
-        bg_client       = create_bigquery_client()
+        bg_client       = create_bigquery_client(credential_filepath=analytics_conf.BIGQUERY_SERVICE_CREDENTIAL_PATH)
         try:
             job_result_rows = execute_query(bg_client, query)
+            bg_client.close()
         except:
             job_result_rows = []
             logger.error('Failed to execute query due to %s', get_tracelog())
